==> react-svg-textures-1.1.3.tgz: package/es/Circles.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { Component } from 'react';
import PropTypes from 'prop-types';
import textures from 'textures';

import Selection from './selection';

var Circles = (_temp = _class = function (_Component) {
  _inherits(Circles, _Component);

  function Circles() {
    _classCallCheck(this, Circles);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Circles.prototype.render = function render() {
    var _this2 = this;

    var t = textures.circles();
    ['size', 'strokeWidth', 'stroke', 'background', 'id', 'complement', 'radius'].forEach(function (key) {
      if (_this2.props[key]) t[key](_this2.props[key]);
    });
    var selection = new Selection();
    t(selection);

    return selection.toReact(this.props.components);
  };

  return Circles;
}(Component), _class.displayName = 'Circles', _class.defaultProps = {
  components: {
    defs: 'defs',
    g: 'g',
    circle: 'circle',
    rect: 'rect',
    pattern: 'pattern',
    path: 'path'
  }
}, _temp);
export { Circles as default };
Circles.propTypes = process.env.NODE_ENV !== "production" ? {
  size: PropTypes.number,
  strokeWidth: PropTypes.number,
  stroke: PropTypes.string,
  background: PropTypes.string,
  id: PropTypes.string,
  complement: PropTypes.bool,
  radius: PropTypes.number,
  components: PropTypes.shape({
    defs: PropTypes.node,
    g: PropTypes.node,
    circle: PropTypes.node,
    rect: PropTypes.node,
    pattern: PropTypes.node,
    path: PropTypes.node
  })
} : {};

==> react-svg-textures-1.4.3.tgz: package/es/Circles.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { Component } from 'react';
import PropTypes from 'prop-types';
import textures from 'textures';

import Selection from './selection';

var Circles = (_temp = _class = function (_Component) {
  _inherits(Circles, _Component);

  function Circles() {
    _classCallCheck(this, Circles);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Circles.prototype.render = function render() {
    var _this2 = this;

    var t = textures.circles();
    ['size', 'strokeWidth', 'stroke', 'fill', 'background', 'id', 'complement', 'radius'].forEach(function (key) {
      if (_this2.props[key]) t[key](_this2.props[key]);
    });
    var selection = new Selection();
    t(selection);

    return selection.toReact(this.props.components);
  };

  return Circles;
}(Component), _class.displayName = 'Circles', _class.defaultProps = {
  components: {
    defs: 'defs',
    g: 'g',
    circle: 'circle',
    rect: 'rect',
    pattern: 'pattern',
    path: 'path'
  }
}, _temp);
export { Circles as default };
Circles.propTypes = process.env.NODE_ENV !== "production" ? {
  size: PropTypes.number,
  strokeWidth: PropTypes.number,
  stroke: PropTypes.string,
  fill: PropTypes.string,
  background: PropTypes.string,
  id: PropTypes.string,
  complement: PropTypes.bool,
  radius: PropTypes.number,
  components: PropTypes.shape({
    defs: PropTypes.node,
    g: PropTypes.node,
    circle: PropTypes.node,
    rect: PropTypes.node,
    pattern: PropTypes.node,
    path: PropTypes.node
  })
} : {};
